@@ -1,9 +1,7 @@
 # -*- coding: utf-8 -*-
 from django import template
 from django.contrib.contenttypes.models import ContentType
-from django.core.exceptions import ObjectDoesNotExist, ImproperlyConfigured
-from django.http import HttpRequest
-from django.template.loader import render_to_string
+from django.db.models import Model
 from django.utils.html import escape
 from seo.models import Seo, Url
 import warnings
@@ -45,6 +43,9 @@ class SeoNode(template.Node):
 
     def _seo_by_content_object(self, context):
         object = template.Variable(self.object).resolve(context)
+        if not isinstance(object, Model):
+            return u''
+
         try:
             seo = Seo.objects.get(
                 content_type=ContentType.objects.get_for_model(
